#
# spec file for package osc-plugin
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (C) 2012,2013, jw@suse.de, Novell Inc., openSUSE.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%define         orig_name osc-plugin-install
Name:           %{orig_name}%{?name_ext}
Version:        0.25
Release:        lp152.4.2
Summary:        Plugin to make package installation easier
License:        GPL-2.0 or GPL-3.0
Group:          Development/Tools/Other
Url:            https://github.com/jnweiger/%{name}
Source:         https://raw.githubusercontent.com/jnweiger/%{name}/master/osc-install.py
Patch0:         boo#1009432_replace_etc_suse_release_by_os_release.patch
%if 0%{?_test}
BuildRequires:  %{orig_name}
BuildRequires:  expect
%if 0%{?suse_version} >= 1330
BuildRequires:  python-certifi
%endif
%else
# Needed for directory ownership
BuildRequires:  osc
Requires:       osc
%if 0%{?!fedora_version:1} && 0%{?!centos_version:1} && 0%{?!scientificlinux_version:1} && 0%{?!rhel_version:1}
Recommends:     rpm-python rpmdevtools
%endif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%define oscplugindir %{_prefix}/lib/osc-plugins

%description
This osc plugin extends osc with the subcommand 'osc install'.
The main effort of this plugin is to free the end-user of the sometimes tedious
task to look up the correct repository URL to be used with zypper.
Dependencies are resolved across projects, just as the online one-click mechanism 
would do. 
The plugin can also guess the best matching platform for your system.

Example usage:
 osc co PROJ PACK ; cd PACK
 do osc build ; vi ... ; osc ci ; osc results
 osc in


Authors:
--------
	Juergen Weigert <jw@suse.de>

%prep
%patch0 -p1 -d %_sourcedir

%build
%if 0%{?_test}
rpm -ql %{orig_name}
cat > test_osc_in << EOF
strace 2
spawn osc in --help
expect "Username: "
send "test"
expect "Password: "
send "foo"
expect "install a package after build via zypper in"
EOF
expect -f test_osc_in

# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else

%install
install -D -m0644 %{S:0} %{buildroot}%{oscplugindir}/osc-install.py

%files
%defattr(-, root, root)
# also glob for byte-compiled (pyc) and optimized byte-compiled (pyo)
# files (they are generated by fedora's brp-python-bytecompile script)
%{oscplugindir}/*.py*

%endif

%changelog
* Sat Jan 20 2018 okurz@suse.com
- Add patch boo#1009432_replace_etc_suse_release_by_os_release.patch to replace obsolete /etc/SuSE-release (boo#1009432)
* Wed Jun  3 2015 jw@owncloud.com
- V0.25 fixing KeyError: 'baseproject'
* Tue Jul  9 2013 suse-tux@gmx.de
- don't use "Recommends" tag for fedora, centos, rhel and scientificlinux builds
- also glob for .pyc and .pyo files (they are generated by
  fedora's brp-python-bytecompile script)
* Mon Jul  8 2013 suse-tux@gmx.de
- adapted code to osc's new plugin mechanism
* Tue Jun 18 2013 jw@suse.com
- fixing https://build.opensuse.org/request/diff/177912
* Thu Jun  6 2013 jw@suse.com
- V0.22 added lispish parens to print statements to make newer osc happy.
* Wed Feb 20 2013 jw@suse.com
- V0.21 shortened useless meta filenames
* Wed Feb  6 2013 jw@suse.com
- V0.20 added _pipe_from_cmd_stdout() to obsolete
  TeePopen() where it misbehaves.
* Wed Dec 26 2012 jw@suse.com
- V0.19 added ymp parsing, so that dependencies from layered
  repos can be installed, just like the one-click would do it.
* Fri Dec  7 2012 jw@suse.com
- V0.18 many fixes during the last year.
  Added direct .rpm file path usage from osc bse
* Fri Sep 21 2012 jw@suse.com
- V0.17, suppress matching .xml files instead of .rpm
* Mon Jul 30 2012 jw@suse.com
- V0.16, added -U, still much todo.
* Tue Feb 21 2012 jw@suse.com
- V0.15, fixed -p, fixed scoring of platforms.
* Wed Jan 25 2012 jw@suse.com
- V0.14, finishing fallback to unpublished.
* Mon Jan 23 2012 jw@suse.com
- V0.13, added TeePopen, experimental unpublished install started.
* Fri Jan 20 2012 jw@suse.com
- V0.12, upload to gitorious.
* Mon May 30 2011 jw@novell.com
- V0.11, it was crappy since 0.9, full of typos that
  often prevent its usage. Another fix.
* Fri May 20 2011 jw@novell.com
- V0.10, oops, typo used proj_name only once.
* Sat May 14 2011 jw@novell.com
- V0.9, SLE support, --arch support, result sorting
* Tue May  3 2011 jw@novell.com
- V0.7, hack for perlish names added.
* Mon Apr 11 2011 jw@novell.com
- V0.6, added -I option, using osc_cache
* Thu Mar 31 2011 jw@novell.com
- v0.5, one param, package. searches for a matching project
* Tue Mar 29 2011 jw@novell.com
- v0.4, ibs support
* Fri Mar 25 2011 jw@novell.com
- v0.3, type 'a' to add the repo permanently.
* Thu Mar 24 2011 jw@novell.com
- initial packaging V0.2
